@@ -1,10 +1,10 @@
 ## -*- coding: utf-8 -*-
 ##
 ##  Jonathan Salwan - 2014-05-12 - ROPgadget tool
-## 
+##
 ##  http://twitter.com/JonathanSalwan
 ##  http://shell-storm.org/project/ROPgadget/
-## 
+##
 
 import argparse
 import sys
@@ -28,11 +28,11 @@ class Args(object):
     def __parse(self, arguments, custom_arguments_provided=False):
         parser = argparse.ArgumentParser(formatter_class=argparse.RawDescriptionHelpFormatter,
                                          description="""description:
-  ROPgadget lets you search your gadgets on a binary. It supports several 
+  ROPgadget lets you search your gadgets on a binary. It supports several
   file formats and architectures and uses the Capstone disassembler for
   the search engine.
 
-formats supported: 
+formats supported:
   - ELF
   - PE
   - Mach-O
@@ -48,7 +48,7 @@ architectures supported:
   - Sparc
 """,
                                          epilog="""examples:
-  ROPgadget.py --binary ./test-suite-binaries/elf-Linux-x86 
+  ROPgadget.py --binary ./test-suite-binaries/elf-Linux-x86
   ROPgadget.py --binary ./test-suite-binaries/elf-Linux-x86 --ropchain
   ROPgadget.py --binary ./test-suite-binaries/elf-Linux-x86 --depth 3
   ROPgadget.py --binary ./test-suite-binaries/elf-Linux-x86 --string "main"
@@ -56,7 +56,7 @@ architectures supported:
   ROPgadget.py --binary ./test-suite-binaries/elf-Linux-x86 --opcode c9c3
   ROPgadget.py --binary ./test-suite-binaries/elf-Linux-x86 --only "mov|ret"
   ROPgadget.py --binary ./test-suite-binaries/elf-Linux-x86 --only "mov|pop|xor|ret"
-  ROPgadget.py --binary ./test-suite-binaries/elf-Linux-x86 --filter "xchg|add|sub"
+  ROPgadget.py --binary ./test-suite-binaries/elf-Linux-x86 --filter "xchg|add|sub|cmov.*"
   ROPgadget.py --binary ./test-suite-binaries/elf-Linux-x86 --norop --nosys
   ROPgadget.py --binary ./test-suite-binaries/elf-Linux-x86 --range 0x08041000-0x08042000
   ROPgadget.py --binary ./test-suite-binaries/elf-Linux-x86 --string main --range 0x080c9aaa-0x080c9aba
@@ -76,11 +76,12 @@ architectures supported:
         parser.add_argument("--memstr",             type=str, metavar="<string>",     help="Search each byte in all readable segment")
         parser.add_argument("--depth",              type=int, metavar="<nbyte>",      default=10, help="Depth for search engine (default 10)")
         parser.add_argument("--only",               type=str, metavar="<key>",        help="Only show specific instructions")
-        parser.add_argument("--filter",             type=str, metavar="<key>",        help="Suppress specific instructions")
+        parser.add_argument("--filter",             type=str, metavar="<key>",        help="Suppress specific mnemonics")
         parser.add_argument("--range",              type=str, metavar="<start-end>",  default="0x0-0x0", help="Search between two addresses (0x...-0x...)")
         parser.add_argument("--badbytes",           type=str, metavar="<byte>",       help="Rejects specific bytes in the gadget's address")
         parser.add_argument("--rawArch",            type=str, metavar="<arch>",       help="Specify an arch for a raw file")
         parser.add_argument("--rawMode",            type=str, metavar="<mode>",       help="Specify a mode for a raw file")
+        parser.add_argument("--rawEndian",          type=str, metavar="<endian>",     help="Specify an endianness for a raw file")
         parser.add_argument("--re",                 type=str, metavar="<re>",         help="Regular expression")
         parser.add_argument("--offset",             type=str, metavar="<hexaddr>",    help="Specify an offset for gadget addresses")
         parser.add_argument("--ropchain",           action="store_true",              help="Enable the ROP chain generation")
@@ -92,10 +93,19 @@ architectures supported:
         parser.add_argument("--nosys",              action="store_true",              help="Disable SYS search engine")
         parser.add_argument("--multibr",            action="store_true",              help="Enable multiple branch gadgets")
         parser.add_argument("--all",                action="store_true",              help="Disables the removal of duplicate gadgets")
+        parser.add_argument("--noinstr",            action="store_true",              help="Disable the gadget instructions console printing")
         parser.add_argument("--dump",               action="store_true",              help="Outputs the gadget bytes")
+        parser.add_argument("--silent",             action="store_true",              help="Disables printing of gadgets during analysis")
+        parser.add_argument("--align",              type=int,                         help="Align gadgets addresses (in bytes)")
 
         self.__args = parser.parse_args(arguments)
 
+        if self.__args.noinstr and self.__args.only:
+            raise ValueError("[Error] --noinstr and --only=<key> can't be used together")
+
+        if self.__args.noinstr and self.__args.re:
+            raise ValueError("[Error] --noinstr and --re=<re> can't be used together")
+
         if self.__args.version:
             self.__printVersion()
             sys.exit(0)
@@ -105,23 +115,19 @@ architectures supported:
             sys.exit(0)
 
         elif self.__args.depth < 2:
-            print("[Error] The depth must be >= 2")
-            sys.exit(-1)
+            raise ValueError("[Error] The depth must be >= 2")
 
         elif not custom_arguments_provided and not self.__args.binary and not self.__args.console:
-            print("[Error] Need a binary filename (--binary/--console or --help)")
-            sys.exit(-1)
+            raise ValueError("[Error] Need a binary filename (--binary/--console or --help)")
 
         elif self.__args.range:
             try:
                 rangeS = int(self.__args.range.split('-')[0], 16)
                 rangeE = int(self.__args.range.split('-')[1], 16)
             except:
-                print("[Error] A range must be set in hexadecimal. Ex: 0x08041000-0x08042000")
-                sys.exit(-1)
+                raise ValueError("[Error] A range must be set in hexadecimal. Ex: 0x08041000-0x08042000")
             if rangeS > rangeE:
-                print("[Error] The start value must be greater than end value")
-                sys.exit(-1)
+                raise ValueError("[Error] The start value must be greater than end value")
 
     def __printVersion(self):
         print("Version:        %s" %(PYROPGADGET_VERSION))
@@ -131,4 +137,3 @@ architectures supported:
 
     def getArgs(self):
         return self.__args
-
